@@ -1,16 +1,15 @@
 package Plack::Middleware::Signposting::JSON;
 
-use strict;
-use warnings;
-
-use parent 'Plack::Middleware';
+use Catmandu::Sane;
+use Catmandu;
+use Catmandu::Fix;
 use JSON qw(decode_json);
 use Plack::Request;
 use Plack::Util::Accessor qw(fix);
-use Catmandu;
-use Catmandu::Fix;
+use Moo;
+use parent 'Plack::Middleware';
 
-our $VERSION = '0.02';
+extends 'Plack::Middleware::Signposting';
 
 sub call {
     my ($self, $env) = @_;
@@ -27,7 +26,7 @@ sub call {
 
         my $content_type = Plack::Util::header_get($res->[1], 'Content-Type') || '';
         # only json responses
-        return unless $content_type =~ m{^application/json}i;
+        return unless $content_type =~ m{^application/json|application\/vnd\.api\+json}i;
         # ignore streaming response for now
         return unless ref $res->[2] eq 'ARRAY';
 
@@ -38,7 +37,6 @@ sub call {
             $data = $data->[0];
         }
 
-        # harcoded fix file
         my $fix = $self->fix ? $self->fix : 'nothing()';
         my $fixer = Catmandu::Fix->new(fixes => [$fix]);
         $fixer->fix($data);
@@ -47,26 +45,12 @@ sub call {
         if ($data->{signs}) {
             Plack::Util::header_push(
                 $res->[1],
-                'Link' => $self->_to_link_format( @{$data->{signs}} )
+                'Link' => $self->to_link_format( @{$data->{signs}} )
             );
         }
     });
 }
 
-# produces the link format
-sub _to_link_format {
-    my ($self, @signs) = @_;
-
-    my $body = join(", ", map {
-        my ($uri, $relation, $type) = @$_;
-        my $link_text = qq|<$uri>; rel="$relation"|;
-        $link_text .= qq|; type="$type"| if $type;
-        $link_text;
-    } @signs);
-
-    $body;
-}
-
 1;
 
 __END__
@@ -75,43 +59,19 @@ __END__
 
 =head1 NAME
 
-Plack::Middleware::Signposting::JSON - A Signposting implementation from JSON content
-
-=begin markdown
-
-[![Build Status](https://travis-ci.org/LibreCat/Plack-Middleware-Signposting.svg?branch=master)](https://travis-ci.org/LibreCat/Plack-Middleware-Signposting)
-[![Coverage Status](https://coveralls.io/repos/github/LibreCat/Plack-Middleware-Signposting/badge.svg?branch=master)](https://coveralls.io/github/LibreCat/Plack-Middleware-Signposting?branch=master)
-
-=end markdown
-
+Plack::Middleware::Signposting::JSON - A Signposting implementation for JSON content
 
 =head1 SYNOPSIS
 
+    my $json_string = '{"hello":"world",....}';
     builder {
        enable "Plack::Middleware::Signposting::JSON";
 
-       sub {200, ['Content-Type' => 'text/plain'], ['hello world']};
+       sub { 200, [ 'Content-Type' => 'text/plain' ], [ $json_string ] };
     };
 
-=head1 DESCRIPTION
-
-Plack::Middleware::Signposting::JSON is a base class for Signposting(https://signposting.org) protocol.
-
-=head1 AUTHOR
-
-Nicolas Steenlant, C<< <nicolas.steenlant at ugent.be> >>
-
-Vitali Peil, C<< <vitali.peil at uni-bielefeld.de> >>
-
-=head1 COPYRIGHT
-
-Copyright 2017 - Vitali Peil
-
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
 =head1 SEE ALSO
 
+L<Plack::Middleware>
+
 =cut
